@@ -19,6 +19,7 @@
 #include <libkleo/formatting.h>
 #include <libkleo/keyfilter.h>
 #include <libkleo/keyfiltermanager.h>
+#include <libkleo/keyhelpers.h>
 #include <libkleo/predicates.h>
 #include <libkleo/systeminfo.h>
 
@@ -326,17 +327,15 @@ QVariant AbstractKeyListModel::headerData(int section, Qt::Orientation o, int ro
             case PrettyEMail:
                 return i18nc("@title:column", "E-Mail");
             case Validity:
-                return i18nc("@title:column", "User-IDs");
+                return i18nc("@title:column", "Status");
             case ValidFrom:
                 return i18nc("@title:column", "Valid From");
             case ValidUntil:
                 return i18nc("@title:column", "Valid Until");
             case TechnicalDetails:
                 return i18nc("@title:column", "Protocol");
-            case ShortKeyID:
-                return i18nc("@title:column", "Key-ID");
             case KeyID:
-                return i18nc("@title:column", "Key-ID");
+                return i18nc("@title:column", "Key ID");
             case Fingerprint:
                 return i18nc("@title:column", "Fingerprint");
             case Issuer:
@@ -397,7 +396,7 @@ QVariant AbstractKeyListModel::data(const QModelIndex &index, int role) const
 
 QVariant AbstractKeyListModel::data(const Key &key, int row, int column, int role) const
 {
-    if (role == Qt::DisplayRole || role == Qt::EditRole || role == Qt::AccessibleTextRole) {
+    if (role == Qt::DisplayRole || role == Qt::EditRole || role == Qt::AccessibleTextRole || role == ClipboardRole) {
         switch (column) {
         case PrettyName: {
             const auto name = Formatting::prettyName(key);
@@ -433,15 +432,11 @@ QVariant AbstractKeyListModel::data(const Key &key, int row, int column, int rol
             }
         case TechnicalDetails:
             return Formatting::type(key);
-        case ShortKeyID:
-            if (role == Qt::AccessibleTextRole) {
-                return Formatting::accessibleHexID(key.shortKeyID());
-            } else {
-                return Formatting::prettyID(key.shortKeyID());
-            }
         case KeyID:
             if (role == Qt::AccessibleTextRole) {
                 return Formatting::accessibleHexID(key.keyID());
+            } else if (role == ClipboardRole) {
+                return QString::fromLatin1(key.keyID());
             } else {
                 return Formatting::prettyID(key.keyID());
             }
@@ -450,6 +445,8 @@ QVariant AbstractKeyListModel::data(const Key &key, int row, int column, int rol
         case Fingerprint:
             if (role == Qt::AccessibleTextRole) {
                 return Formatting::accessibleHexID(key.primaryFingerprint());
+            } else if (role == ClipboardRole) {
+                return QString::fromLatin1(key.primaryFingerprint());
             } else {
                 return Formatting::prettyID(key.primaryFingerprint());
             }
@@ -506,7 +503,7 @@ QVariant AbstractKeyListModel::data(const Key &key, int row, int column, int rol
             if (role == Qt::AccessibleTextRole) {
                 return Formatting::accessibleHexID(key.subkey(0).keyGrip());
             } else {
-                return Formatting::prettyID(key.subkey(0).keyGrip());
+                return QString::fromLatin1(key.subkey(0).keyGrip());
             }
         case NumColumns:
             break;
@@ -514,9 +511,7 @@ QVariant AbstractKeyListModel::data(const Key &key, int row, int column, int rol
     } else if (role == Qt::ToolTipRole) {
         return Formatting::toolTip(key, toolTipOptions());
     } else if (role == Qt::FontRole) {
-        return KeyFilterManager::instance()->font(key,
-                                                  (column == ShortKeyID || column == KeyID || column == Fingerprint) ? QFont(QStringLiteral("monospace"))
-                                                                                                                     : QFont());
+        return KeyFilterManager::instance()->font(key, (column == KeyID || column == Fingerprint) ? QFont(QStringLiteral("monospace")) : QFont());
     } else if (role == Qt::DecorationRole) {
         return column == Icon ? returnIfValid(KeyFilterManager::instance()->icon(key)) : QVariant();
     } else if (role == Qt::BackgroundRole) {
@@ -550,7 +545,6 @@ QVariant AbstractKeyListModel::data(const KeyGroup &group, int column, int role)
         case PrettyEMail:
         case ValidFrom:
         case ValidUntil:
-        case ShortKeyID:
         case KeyID:
         case Fingerprint:
         case Issuer:
@@ -576,7 +570,7 @@ QVariant AbstractKeyListModel::data(const KeyGroup &group, int column, int role)
         }
         return Kleo::all_of(group.keys(),
                             [](const auto &key) {
-                                return key.hasEncrypt();
+                                return Kleo::canBeUsedForEncryption(key);
                             })
             ? QIcon::fromTheme(QStringLiteral("group"))
             : QIcon::fromTheme(QStringLiteral("emblem-warning"));
